@@ -5,7 +5,7 @@
 #include <unistd.h>
 #include <qobject.h>
 #include <qfile.h>
-#include <qtstream.h>
+#include <qtextstream.h>
 #include <qstring.h>
 #include <qstrlist.h>
 #include <qlist.h>
