@@ -2,18 +2,18 @@
 #define main_included
 
 
-#include <qpushbt.h>
+#include <qpushbutton.h>
 #include <qfile.h>
 #include <qstring.h>
 #include <qstrlist.h>
 #include <qfile.h>
-#include <qtstream.h>
+#include <qtextstream.h>
 #include <kconfig.h>
 #include <ktabctl.h>
 #include <ktopwidget.h>
-#include <qmsgbox.h>
+#include <qmessagebox.h>
 #include <qmenubar.h>
-#include <qfiledlg.h>
+#include <qfiledialog.h>
 
 #include "daten2.h"
 #include "mymaintable.h"
