@@ -7,7 +7,7 @@
 
 #include <ktablistbox.h>
 #include <qstrlist.h>
-#include <qpopmenu.h>
+#include <qpopupmenu.h>
 #include <qpoint.h>
 
 #define QCharDict QDict<char>
