@@ -11,7 +11,7 @@
 #define myservicewidget_included
 
 #include <qdialog.h>
-#include <qtabdlg.h>
+#include <qtabdialog.h>
 
 #include "daten2.h"
 
