@@ -24,7 +24,7 @@ public:
 	virtual ~newservice();
 	QString newservice_name;
 	QString newservice_path;
-	int newservice_type;
+	QString newservice_type;
 
 private:
 //	KLocale klocale;
